@@ -7,7 +7,6 @@ import sys
 sys.path.append('..')
 
 import geoip2.database
-import geoip2.errors
 
 if sys.version_info[:2] == (2, 6):
     import unittest2 as unittest
@@ -58,7 +57,7 @@ class TestReader(unittest.TestCase):
         reader = geoip2.database.Reader(
             'tests/data/test-data/GeoIP2-City-Test.mmdb')
         with self.assertRaisesRegex(ValueError,
-                                    'The value "invalid" is not a valid '
-                                    'IP address.'):
+                                    "u?'invalid' does not appear to be an "
+                                    "IPv4 or IPv6 address"):
             reader.city('invalid')
         reader.close()
